..
    Copyright (C) 2020 CERN.

    Babel-EDTF is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Authors
=======

Localization of Extended Date Time Format level 0 strings.

- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
